@@ -19,10 +19,8 @@ use Symbol;
 use Data::FormValidator::Filters qw/:filters/;
 use Data::FormValidator::Constraints (qw/:validators :matchers/);
 use vars qw/$AUTOLOAD $VERSION/;
-use overload
-  'bool' => \&_bool_overload_based_on_success;
 
-$VERSION = 4.00;
+$VERSION = 4.00_01;
 
 =pod
 
@@ -260,14 +258,8 @@ sub _process {
 	}
 
     # Fill defaults
-    while ( my ($field,$value) = each %{$profile->{defaults}} ) {
-        unless(exists $valid{$field}) {
-            if (ref($value) && ref($value) eq "CODE") {
-                $valid{$field} = $value->($self);
-            } else {
-                $valid{$field} = $value;
-            }
-        }
+	while ( my ($field,$value) = each %{$profile->{defaults}} ) {
+		$valid{$field} = $value unless exists $valid{$field};
 	}
 
     # Check for required fields
@@ -305,22 +297,21 @@ sub _process {
     }
 
     # add in the constraints from the regexp maps
-    # We don't want to modify the profile, so we use a new variable.
 	$profile->{constraints} ||= {};
-	my $private_constraints = {
+	$profile->{constraints} = {
 	    %{ $profile->{constraints} }, 	
 		_add_constraints_from_map($profile,'constraint',\%valid),
 	};
 	$profile->{constraint_methods} ||= {};
-	my $private_constraint_methods = {
+	$profile->{constraint_methods} = {
 	    %{ $profile->{constraint_methods} }, 	
 		_add_constraints_from_map($profile,'constraint_method',\%valid),
 	};
 
-	$self->_check_constraints($private_constraints,\%valid,$untaint_all,\%untaint_hash);
+	$self->_check_constraints($profile->{constraints},\%valid,$untaint_all,\%untaint_hash);
 
 	my $force_method_p = 1;
-	$self->_check_constraints($private_constraint_methods,\%valid,$untaint_all,\%untaint_hash, $force_method_p);
+	$self->_check_constraints($profile->{constraint_methods},\%valid,$untaint_all,\%untaint_hash, $force_method_p);
 
     # all invalid fields are removed from valid hash
 	foreach my $field (keys %{ $self->{invalid} }) {
@@ -350,12 +341,6 @@ sub _process {
 This method returns true if there were no invalid or missing fields,
 else it returns false.
 
-As a shorthand, When the $results object is used in boolean context, it is overloaded
-to use the value of success() instead. That allows creation of a syntax like this one used
-in C<CGI::Application::Plugin::ValidateRM>:
-
- my $results = $self->check_rm('form_display','_form_profile') || return $self->dfv_error_page;
-
 =cut
 
 sub success {
@@ -1033,11 +1018,6 @@ sub _add_constraints_from_map {
 	return %result;
 }
 
-sub _bool_overload_based_on_success {
-    my $results = shift;
-    return $results->success()
-}
-
 # =head2 _check_constraints()
 #
 # $self->_check_constraints(
